'use strict';

var chunkMR6KOKSU_cjs = require('./chunk-MR6KOKSU.cjs');
require('./chunk-XZCJTQWB.cjs');
var path = require('path');
var core = require('@kubb/core');
var transformers = require('@kubb/core/transformers');
var utils = require('@kubb/core/utils');
var pluginOas = require('@kubb/plugin-oas');
var pluginTs = require('@kubb/plugin-ts');
var pluginZod = require('@kubb/plugin-zod');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var path__default = /*#__PURE__*/_interopDefault(path);

var pluginVueQueryName = "plugin-vue-query";
var pluginVueQuery = core.createPlugin((options) => {
  const {
    output = { path: "hooks" },
    group,
    exclude = [],
    include,
    override = [],
    parser = "client",
    infinite,
    transformers: transformers$1 = {},
    pathParamsType = "inline",
    mutation = {},
    query = {},
    generators = [chunkMR6KOKSU_cjs.queryGenerator, chunkMR6KOKSU_cjs.infiniteQueryGenerator, chunkMR6KOKSU_cjs.mutationGenerator].filter(Boolean)
  } = options;
  const template = group?.output ? group.output : `${output.path}/{{tag}}Controller`;
  return {
    name: pluginVueQueryName,
    options: {
      output: {
        exportType: "barrelNamed",
        ...output
      },
      baseURL: void 0,
      client: {
        importPath: "@kubb/plugin-client/client",
        dataReturnType: "data",
        pathParamsType: "inline",
        ...options.client
      },
      infinite: infinite ? {
        queryParam: "id",
        initialPageParam: 0,
        cursorParam: void 0,
        ...infinite
      } : false,
      query: {
        key: (key) => key,
        methods: ["get"],
        importPath: "@tanstack/vue-query",
        ...query
      },
      mutation: {
        key: (key) => key,
        methods: ["post", "put", "patch", "delete"],
        importPath: "@tanstack/vue-query",
        ...mutation
      },
      pathParamsType,
      parser
    },
    pre: [pluginOas.pluginOasName, pluginTs.pluginTsName, parser === "zod" ? pluginZod.pluginZodName : void 0].filter(Boolean),
    resolvePath(baseName, pathMode, options2) {
      const root = path__default.default.resolve(this.config.root, this.config.output.path);
      const mode = pathMode ?? core.FileManager.getMode(path__default.default.resolve(root, output.path));
      if (mode === "single") {
        return path__default.default.resolve(root, output.path);
      }
      if (options2?.tag && group?.type === "tag") {
        const tag = transformers.camelCase(options2.tag);
        return path__default.default.resolve(root, utils.renderTemplate(template, { tag }), baseName);
      }
      return path__default.default.resolve(root, output.path, baseName);
    },
    resolveName(name, type) {
      let resolvedName = transformers.camelCase(name);
      if (type === "file" || type === "function") {
        resolvedName = transformers.camelCase(name, {
          isFile: type === "file"
        });
      }
      if (type === "type") {
        resolvedName = transformers.pascalCase(name);
      }
      if (type) {
        return transformers$1?.name?.(resolvedName, type) || resolvedName;
      }
      return resolvedName;
    },
    async buildStart() {
      const [swaggerPlugin] = core.PluginManager.getDependedPlugins(this.plugins, [pluginOas.pluginOasName]);
      const oas = await swaggerPlugin.context.getOas();
      const root = path__default.default.resolve(this.config.root, this.config.output.path);
      const mode = core.FileManager.getMode(path__default.default.resolve(root, output.path));
      const baseURL = await swaggerPlugin.context.getBaseURL();
      const operationGenerator = new pluginOas.OperationGenerator(
        {
          ...this.plugin.options,
          baseURL
        },
        {
          oas,
          pluginManager: this.pluginManager,
          plugin: this.plugin,
          contentType: swaggerPlugin.context.contentType,
          exclude,
          include,
          override,
          mode
        }
      );
      const files = await operationGenerator.build(...generators);
      await this.addFile(...files);
      if (this.config.output.exportType) {
        const barrelFiles = await this.fileManager.getBarrelFiles({
          root,
          output,
          files: this.fileManager.files,
          meta: {
            pluginKey: this.plugin.key
          },
          logger: this.logger
        });
        await this.addFile(...barrelFiles);
      }
    }
  };
});

exports.pluginVueQuery = pluginVueQuery;
exports.pluginVueQueryName = pluginVueQueryName;
//# sourceMappingURL=index.cjs.map
//# sourceMappingURL=index.cjs.map